==> olvwm3.1.tar.z: olvwm3.1/Debug.c <==
/*
 *      (c) Copyright 1989 Sun Microsystems, Inc. Sun design patents
 *      pending in the U.S. and foreign countries. See LEGAL_NOTICE
 *      file for terms of the license.
 */

#ident  "@(#)Debug.c	1.2 olvwm version 1/27/92"

/*
 * Based on
#ident	"@(#)Debug.c	26.5	91/09/14 SMI"
 *
 */

#include <errno.h>
#include <stdio.h>
#include <X11/Xos.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>

#include "i18n.h"
#include "olwm.h"
#include "win.h"

char *eventNames[] = {
	"<EventZero>",
	"<EventOne>",
	"KeyPress",
	"KeyRelease",
	"ButtonPress",
	"ButtonRelease",
	"MotionNotify",
	"EnterNotify",
	"LeaveNotify",
	"FocusIn",
	"FocusOut",
	"KeymapNotify",
	"Expose",
	"GraphicsExpose",
	"NoExpose",
	"VisibilityNotify",
	"CreateNotify",
	"DestroyNotify",
	"UnmapNotify",
	"MapNotify",
	"MapRequest",
	"ReparentNotify",
	"ConfigureNotify",
	"ConfigureRequest",
	"GravityNotify",
	"ResizeRequest",
	"CirculateNotify",
	"CirculateRequest",
	"PropertyNotify",
	"SelectionClear",
	"SelectionRequest",
	"SelectionNotify",
	"ColormapNotify",
	"ClientMessage",
	"MappingNotify",
};

DebugEvent(ep, str)
	XEvent	*ep;
	char	*str;
{
	fprintf(stderr, "%s:%s - ", str, eventNames[ep->type]);
	fflush(stderr);
}

static char *typeNames[] = {
	"Frame",
	"Icon",
	"Resize",
	"Pushpin",
	"Button",
	"Pane",
	"IconPane",
	"Colormap",
	"Menu",
	"PinMenu",
	"NoFocus",
	"Root",
	"Busy",
	"Virtual",
};

DebugWindow(win)
WinGeneric *win;
{
	if (win == NULL)
		fprintf(stderr, "other window - ");
	else
		fprintf(stderr, "win %x (self %d) %s - ",win,win->core.self,
			typeNames[win->core.kind]);
	fflush(stderr);
}

==> olvwm3.3.tar.z: olvwm3.3/Debug.c <==
/*
 *      (c) Copyright 1989 Sun Microsystems, Inc. Sun design patents
 *      pending in the U.S. and foreign countries. See LEGAL_NOTICE
 *      file for terms of the license.
 */

#ifdef IDENT
#ident  "@(#)Debug.c	1.3 olvwm version 11/25/92"
#endif

/*
 * Based on
#ident	"@(#)Debug.c	26.5	91/09/14 SMI"
 *
 */

#include <errno.h>
#include <stdio.h>
#include <X11/Xos.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>

#include "i18n.h"
#include "olwm.h"
#include "win.h"

char *eventNames[] = {
	"<EventZero>",
	"<EventOne>",
	"KeyPress",
	"KeyRelease",
	"ButtonPress",
	"ButtonRelease",
	"MotionNotify",
	"EnterNotify",
	"LeaveNotify",
	"FocusIn",
	"FocusOut",
	"KeymapNotify",
	"Expose",
	"GraphicsExpose",
	"NoExpose",
	"VisibilityNotify",
	"CreateNotify",
	"DestroyNotify",
	"UnmapNotify",
	"MapNotify",
	"MapRequest",
	"ReparentNotify",
	"ConfigureNotify",
	"ConfigureRequest",
	"GravityNotify",
	"ResizeRequest",
	"CirculateNotify",
	"CirculateRequest",
	"PropertyNotify",
	"SelectionClear",
	"SelectionRequest",
	"SelectionNotify",
	"ColormapNotify",
	"ClientMessage",
	"MappingNotify",
};

void
DebugEvent(ep, str)
	XEvent	*ep;
	char	*str;
{
	(void) fprintf(stderr, "%s:%s - ", str, eventNames[ep->type]);
	(void) fflush(stderr);
}

static char *typeNames[] = {
	"Frame",
	"Icon",
	"Resize",
	"Pushpin",
	"Button",
	"Pane",
	"IconPane",
	"Colormap",
	"Menu",
	"PinMenu",
	"NoFocus",
	"Root",
	"Busy",
	"Virtual",
};

void
DebugWindow(win)
WinGeneric *win;
{
	if (win == NULL)
		(void) fprintf(stderr, "other window - ");
	else
		(void) fprintf(stderr, "win %x (self %d) %s - ",win,win->core.self,
			typeNames[win->core.kind]);
	(void) fflush(stderr);
}
